diff --git a/data/projects/templates/default.mpt b/data/projects/templates/default.mpt
new file mode 100644
index 000000000..18fcdd925
--- /dev/null
+++ b/data/projects/templates/default.mpt
@@ -0,0 +1,89 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+Enter project notes here
]]>
+
+
+
+
diff --git a/src/core/ConfigManager.cpp b/src/core/ConfigManager.cpp
index c9cf77357..5ccb4d345 100644
--- a/src/core/ConfigManager.cpp
+++ b/src/core/ConfigManager.cpp
@@ -282,7 +282,8 @@ void ConfigManager::addRecentlyOpenedProject( const QString & file )
{
QFileInfo recentFile( file );
if( recentFile.suffix().toLower() == "mmp" ||
- recentFile.suffix().toLower() == "mmpz" )
+ recentFile.suffix().toLower() == "mmpz" ||
+ recentFile.suffix().toLower() == "mpt" )
{
m_recentlyOpenedProjects.removeAll( file );
if( m_recentlyOpenedProjects.size() > 50 )
diff --git a/src/core/main.cpp b/src/core/main.cpp
index 5dbea3099..617e3804d 100644
--- a/src/core/main.cpp
+++ b/src/core/main.cpp
@@ -846,13 +846,15 @@ int main( int argc, char * * argv )
else if( ConfigManager::inst()->
value( "app", "openlastproject" ).toInt() &&
!ConfigManager::inst()->
- recentlyOpenedProjects().isEmpty() )
+ recentlyOpenedProjects().isEmpty() &&
+ !recoveryFilePresent )
{
QString f = ConfigManager::inst()->
recentlyOpenedProjects().first();
QFileInfo recentFile( f );
- if ( recentFile.exists() )
+ if ( recentFile.exists() &&
+ recentFile.suffix().toLower() != "mpt" )
{
Engine::getSong()->loadProject( f );
}
diff --git a/src/gui/MainWindow.cpp b/src/gui/MainWindow.cpp
index 09524238e..ddd2faacf 100644
--- a/src/gui/MainWindow.cpp
+++ b/src/gui/MainWindow.cpp
@@ -876,8 +876,8 @@ void MainWindow::updateRecentlyOpenedProjectsMenu()
m_recentlyOpenedProjectsMenu->clear();
QStringList rup = ConfigManager::inst()->recentlyOpenedProjects();
// The file history goes 30 deep but we only show the 15
// most recent ones that we can open.
int shownInMenu = 0;
for( QStringList::iterator it = rup.begin(); it != rup.end(); ++it )
{
@@ -885,6 +885,11 @@ void MainWindow::updateRecentlyOpenedProjectsMenu()
if ( recentFile.exists() &&
*it != ConfigManager::inst()->recoveryFile() )
{
+ if( recentFile.suffix().toLower() == "mpt" )
+ {
+ continue;
+ }
+
m_recentlyOpenedProjectsMenu->addAction(
embed::getIconPixmap( "project_file" ), *it );
#ifdef LMMS_BUILD_APPLE
@@ -876,8 +876,8 @@ void MainWindow::updateRecentlyOpenedProjectsMenu()
m_recentlyOpenedProjectsMenu->clear();
QStringList rup = ConfigManager::inst()->recentlyOpenedProjects();
-// The file history goes 30 deep but we only show the 15
-// most recent ones that we can open.
+// The file history goes 50 deep but we only show the 15
+// most recent ones that we can open and omit .mpt files.
int shownInMenu = 0;
for( QStringList::iterator it = rup.begin(); it != rup.end(); ++it )